@@ -10,7 +10,7 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::Config;
-$App::SpreadRevolutionaryDate::Config::VERSION = '0.21';
+$App::SpreadRevolutionaryDate::Config::VERSION = '0.22';
 # ABSTRACT: Companion class of L<App::SpreadRevolutionaryDate>, to handle configuration file and command line arguments, subclass of L<AppConfig>.
 
 use Moose;
@@ -166,6 +166,8 @@ sub new {
     'freenode_password' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'fp'},
     'freenode_test_channels' => {ARGCOUNT => ARGCOUNT_LIST, ALIAS => 'ftc'},
     'freenode_channels' => {ARGCOUNT => ARGCOUNT_LIST, ALIAS => 'fc'},
+    'revolutionarydate_acab' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 'ra'},
+    'promptuser_default' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'pud'},
   );
 
   # Rewind configuration file if needed and read it
@@ -299,6 +301,9 @@ sub get_msgmaker_arguments {
         && !exists($msgmaker_args{acab})
         && $self->acab;
 
+  # Do not prompt if PromptUser default is set
+  $ENV{PERL_MM_USE_DEFAULT} = 1 if $msgmaker_args{default};
+
   return %msgmaker_args;
 }
 
@@ -330,8 +335,8 @@ Usage: $0 <OPTIONS>
     --freenode_password|-fp <passwd>: define Freenode password
     --freenode_test_channels|-ftc <channel_1>  [--freenode_test_channels|-ftc <channel_2> […--freenode_test_channels|-ftc <channel_n>]]: define Freenode channels
     --freenode_channels|-fc <channel_1>  [--freenode_channels|-fc <channel_2> […--freenode_channels|-fc <channel_n>]]: define Freenode test channels
-    --revolutionarydate-acab: pretend it is 01:31:20 (default: false)
-    --promptuser-default <msg>: define default message when --msgmaker=PromptUser (default: 'Goodbye old world, hello revolutionary worlds')
+    --revolutionarydate_acab | -ra: pretend it is 01:31:20 (default: false)
+    --promptuser_default|-pud <msg>: define default message when --msgmaker=PromptUser (default: 'Goodbye old world, hello revolutionary worlds')
 USAGE
  exit 0;
 }
@@ -359,7 +364,7 @@ App::SpreadRevolutionaryDate::Config - Companion class of L<App::SpreadRevolutio
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 METHODS
 
